@@ -969,12 +969,25 @@ static void steve_handle_sigusr1(evutil_socket_t, short, void *userdata) {
 	std::print(stderr, "steve: currently {} tokens available out of {}\n",
 			state->tokens, state->jobs);
 	for (const auto &it : state->processes) {
-		std::print(stderr, "{} holds {} tokens:\n",
+		std::print(stderr, "  {} holds {} tokens:\n",
 			steve_process_id(it.first, &it.second), it.second.tokens_held);
 		for (const auto &jt : it.second.running_jobs)
-			std::print(stderr, "  job 0x{:02x} running for {}\n", jt.first,
+			std::print(stderr, "    job 0x{:02x} running for {}\n", jt.first,
 				std::chrono::duration<double>(current_time - jt.second.start_time));
 	}
+
+	if (!state->waiters.empty()) {
+		std::print(stderr, "  {} processes waiting for a job token (in order):\n",
+				state->waiters.size());
+		for (const auto &it : state->waiters) {
+			if (std::holds_alternative<fuse_req_t>(it.handle))
+				std::print(stderr, "    PID {} is performing a blocking read\n", it.pid);
+			else if (std::holds_alternative<fuse_pollhandle *>(it.handle))
+				std::print(stderr, "    PID {} is polling\n", it.pid);
+			else
+				assert(0 && "invalid waiter");
+		}
+	}
 }
 
 static void steve_handle_cuse(evutil_socket_t, short, void *userdata) {
