@@ -100,6 +100,19 @@ static int run_command(int jobserver_fd, char **argv, const char *jobserver_path
 		}
 		new_makeflags += "--jobserver-auth=fifo:";
 		new_makeflags += jobserver_path;
+
+		/* Some clients (e.g. LLVM) try to read -j from MAKEFLAGS to determine
+		 * the upper jobs bound.  To accommodate them, try to grab the job count
+		 * from steve.  Note that this is not 100% reliable, as it doesn't
+		 * account for job token count changing at runtime.
+		 *
+		 * We do not need to offset the value since stevie takes one job token,
+		 * so we match GNU make exactly.
+		 */
+		int64_t num_jobs;
+		if (ioctl(jobserver_fd, STEVE_IOC_GET_JOBS, &num_jobs) == 0)
+			new_makeflags += std::format(" -j{}", num_jobs);
+
 		if (setenv("MAKEFLAGS", new_makeflags.c_str(), 1) == -1) {
 			std::print(stderr, "Unable to set MAKEFLAGS={}\n", new_makeflags);
 			_exit(1);
